@@ -207,7 +207,6 @@ import time
 import traceback
 import os
 from functools import wraps
-from itertools import count
 
 os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
 import pygame
@@ -437,12 +436,13 @@ class Robot(pygame.sprite.Sprite):
     * Current colors: ```[Green, Orange, Pink, Teal, Purple]```
     * Colors are automatically assigned based on the order Robots are added to the World.
 """
-    __ids = count(0)
+    __num_of_robots = 0
 
     def __init__(self, x, y, direction, num_of_beepers, color=-1):
         # color is an int, maybe add string colors eventually
         super().__init__()
-        self.id = next(self.__ids)
+        Robot.__num_of_robots += 1
+        self.id = Robot.__num_of_robots
         self.__color = SLEEVE_COLORS[(self.id if color == -1 else color) % len(SLEEVE_COLORS)]
         self.__tile_x = x
         self.__tile_y = y
